@@ -73,10 +73,10 @@ right_paddle_speed=12, cake_paddle=True, max_cycles=900, bounce_randomness=False
 
 """
 
-import gym
+import gymnasium
 import numpy as np
 import pygame
-from gym.utils import EzPickle, seeding
+from gymnasium.utils import EzPickle, seeding
 
 from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
@@ -147,6 +147,7 @@ class CooperativePong:
         bounce_randomness=False,
         max_reward=100,
         off_screen_penalty=-10,
+        render_mode=None,
         render_ratio=2,
         kernel_window_length=2,
     ):
@@ -168,22 +169,25 @@ class CooperativePong:
         self.off_screen_penalty = off_screen_penalty
 
         # define action and observation spaces
-        self.action_space = [gym.spaces.Discrete(3) for _ in range(self.num_agents)]
+        self.action_space = [
+            gymnasium.spaces.Discrete(3) for _ in range(self.num_agents)
+        ]
         original_shape = original_obs_shape(
             self.s_width, self.s_height, kernel_window_length=kernel_window_length
         )
         original_color_shape = (original_shape[0], original_shape[1], 3)
         self.observation_space = [
-            gym.spaces.Box(
+            gymnasium.spaces.Box(
                 low=0, high=255, shape=(original_color_shape), dtype=np.uint8
             )
             for _ in range(self.num_agents)
         ]
         # define the global space of the environment or state
-        self.state_space = gym.spaces.Box(
+        self.state_space = gymnasium.spaces.Box(
             low=0, high=255, shape=((self.s_height, self.s_width, 3)), dtype=np.uint8
         )
 
+        self.render_mode = render_mode
         self.renderOn = False
 
         # set speed
@@ -258,16 +262,24 @@ class CooperativePong:
         self.renderOn = True
         self.draw()
 
-    def render(self, mode="human"):
-        if not self.renderOn and mode == "human":
+    def render(self):
+        if self.render_mode is None:
+            gymnasium.logger.WARN(
+                "You are calling render method without specifying any render mode."
+            )
+            return
+
+        if not self.renderOn and self.render_mode == "human":
             # sets self.renderOn to true and initializes display
             self.enable_render()
 
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
-        if mode == "human":
+        if self.render_mode == "human":
             pygame.display.flip()
         return (
-            np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+            np.transpose(observation, axes=(1, 0, 2))
+            if self.render_mode == "rgb_array"
+            else None
         )
 
     def observe(self):
@@ -357,6 +369,7 @@ class raw_env(AECEnv, EzPickle):
 
         self.seed()
 
+        self.render_mode = self.env.render_mode
         self.agents = self.env.agents[:]
         self.possible_agents = self.agents[:]
         self._agent_selector = agent_selector(self.agents)
@@ -410,8 +423,8 @@ class raw_env(AECEnv, EzPickle):
     def close(self):
         self.env.close()
 
-    def render(self, mode="human"):
-        return self.env.render(mode)
+    def render(self):
+        return self.env.render()
 
     def step(self, action):
         if (
