@@ -85,12 +85,12 @@ ball_elasticity=1.5, max_cycles=125)
 
 import math
 
-import gym
+import gymnasium
 import numpy as np
 import pygame
 import pymunk
 import pymunk.pygame_util
-from gym.utils import EzPickle, seeding
+from gymnasium.utils import EzPickle, seeding
 
 from pettingzoo import AECEnv
 from pettingzoo.utils import agent_selector, wrappers
@@ -147,6 +147,7 @@ class raw_env(AECEnv, EzPickle):
         ball_friction=0.3,
         ball_elasticity=1.5,
         max_cycles=125,
+        render_mode=None,
     ):
         EzPickle.__init__(
             self,
@@ -159,6 +160,7 @@ class raw_env(AECEnv, EzPickle):
             ball_friction,
             ball_elasticity,
             max_cycles,
+            render_mode,
         )
         self.dt = 1.0 / FPS
         self.n_pistons = n_pistons
@@ -189,7 +191,7 @@ class raw_env(AECEnv, EzPickle):
             zip(
                 self.agents,
                 [
-                    gym.spaces.Box(
+                    gymnasium.spaces.Box(
                         low=0,
                         high=255,
                         shape=(obs_height, self.piston_width * 3, 3),
@@ -204,14 +206,14 @@ class raw_env(AECEnv, EzPickle):
             self.action_spaces = dict(
                 zip(
                     self.agents,
-                    [gym.spaces.Box(low=-1, high=1, shape=(1,))] * self.n_pistons,
+                    [gymnasium.spaces.Box(low=-1, high=1, shape=(1,))] * self.n_pistons,
                 )
             )
         else:
             self.action_spaces = dict(
-                zip(self.agents, [gym.spaces.Discrete(3)] * self.n_pistons)
+                zip(self.agents, [gymnasium.spaces.Discrete(3)] * self.n_pistons)
             )
-        self.state_space = gym.spaces.Box(
+        self.state_space = gymnasium.spaces.Box(
             low=0,
             high=255,
             shape=(self.screen_height, self.screen_width, 3),
@@ -221,6 +223,7 @@ class raw_env(AECEnv, EzPickle):
         pygame.init()
         pymunk.pygame_util.positive_y_is_up = False
 
+        self.render_mode = render_mode
         self.renderOn = False
         self.screen = pygame.Surface((self.screen_width, self.screen_height))
         self.max_cycles = max_cycles
@@ -593,8 +596,14 @@ class raw_env(AECEnv, EzPickle):
         local_reward = 0.5 * (prev_position - curr_position)
         return local_reward
 
-    def render(self, mode="human"):
-        if mode == "human" and not self.renderOn:
+    def render(self):
+        if self.render_mode is None:
+            gymnasium.logger.WARN(
+                "You are calling render method without specifying any render mode."
+            )
+            return
+
+        if self.render_mode == "human" and not self.renderOn:
             # sets self.renderOn to true and initializes display
             self.enable_render()
 
@@ -602,10 +611,12 @@ class raw_env(AECEnv, EzPickle):
         self.draw()
 
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
-        if mode == "human":
+        if self.render_mode == "human":
             pygame.display.flip()
         return (
-            np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+            np.transpose(observation, axes=(1, 0, 2))
+            if self.render_mode == "rgb_array"
+            else None
         )
 
     def step(self, action):
@@ -671,5 +682,8 @@ class raw_env(AECEnv, EzPickle):
         self._cumulative_rewards[agent] = 0
         self._accumulate_rewards()
 
+        if self.render_mode == "human":
+            self.render()
+
 
 # Game art created by J K Terry
