@@ -83,6 +83,7 @@ whose turn it is. Taking an illegal move ends the game with a reward of -1 for t
 
 import os
 
+import gymnasium
 import numpy as np
 import pygame
 
@@ -126,10 +127,17 @@ class raw_env(RLCardBase):
         "render_fps": 1,
     }
 
-    def __init__(self, num_players=2):
+    def __init__(self, num_players=2, render_mode=None):
         super().__init__("limit-holdem", num_players, (72,))
+        self.render_mode = render_mode
+
+    def render(self):
+        if self.render_mode is None:
+            gymnasium.logger.WARN(
+                "You are calling render method without specifying any render mode."
+            )
+            return
 
-    def render(self, mode="human"):
         def calculate_width(self, screen_width, i):
             return int(
                 (
@@ -154,15 +162,14 @@ class raw_env(RLCardBase):
             + np.ceil(len(self.possible_agents) / 2) * (screen_height * 1 / 2)
         )
 
-        if self.screen is None:
-            if mode == "human":
+        if self.render_mode == "human":
+            if self.screen is None:
                 pygame.init()
                 self.screen = pygame.display.set_mode((screen_width, screen_height))
-            else:
-                pygame.font.init()
-                self.screen = pygame.Surface((screen_width, screen_height))
-        if mode == "human":
             pygame.event.get()
+        elif self.screen is None:
+            pygame.font.init()
+            self.screen = pygame.Surface((screen_width, screen_height))
 
         # Setup dimensions for card size and setup for colors
         tile_size = screen_height * 2 / 10
@@ -357,11 +364,13 @@ class raw_env(RLCardBase):
                         ),
                     )
 
-        if mode == "human":
+        if self.render_mode == "human":
             pygame.display.update()
 
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
 
         return (
-            np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+            np.transpose(observation, axes=(1, 0, 2))
+            if self.render_mode == "rgb_array"
+            else None
         )
