@@ -117,9 +117,10 @@ If the game ends in a draw, both players will receive a reward of 0.
 
 import os
 
+import gymnasium
 import numpy as np
 import pygame
-from gym.spaces import Discrete
+from gymnasium.spaces import Discrete
 
 from pettingzoo import AECEnv
 from pettingzoo.utils import agent_selector, wrappers
@@ -170,7 +171,7 @@ class raw_env(AECEnv):
         "render_fps": 2,
     }
 
-    def __init__(self, num_actions=3, max_cycles=15):
+    def __init__(self, num_actions=3, max_cycles=15, render_mode=None):
         self.max_cycles = max_cycles
 
         # number of actions must be odd and greater than 3
@@ -194,6 +195,7 @@ class raw_env(AECEnv):
             agent: Discrete(1 + num_actions) for agent in self.agents
         }
 
+        self.render_mode = render_mode
         self.screen = None
 
         self.reinit()
@@ -221,7 +223,13 @@ class raw_env(AECEnv):
 
         self.num_moves = 0
 
-    def render(self, mode="human"):
+    def render(self):
+        if self.render_mode is None:
+            gymnasium.logger.WARN(
+                "You are calling render method without specifying any render mode."
+            )
+            return
+
         def offset(i, size, offset=0):
             if i == 0:
                 return -(size) - offset
@@ -231,15 +239,14 @@ class raw_env(AECEnv):
         screen_height = 350
         screen_width = int(screen_height * 5 / 14)
 
-        if self.screen is None:
-            if mode == "human":
+        if self.render_mode == "human":
+            if self.screen is None:
                 pygame.init()
                 self.screen = pygame.display.set_mode((screen_width, screen_height))
-            else:
-                pygame.font.init()
-                self.screen = pygame.Surface((screen_width, screen_height))
-        if mode == "human":
             pygame.event.get()
+        elif self.screen is None:
+            pygame.font.init()
+            self.screen = pygame.Surface((screen_width, screen_height))
 
         # Load and all of the necessary images
         paper = get_image(os.path.join("img", "Paper.png"))
@@ -413,13 +420,15 @@ class raw_env(AECEnv):
                         ),
                     )
 
-        if mode == "human":
+        if self.render_mode == "human":
             pygame.display.update()
 
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
 
         return (
-            np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+            np.transpose(observation, axes=(1, 0, 2))
+            if self.render_mode == "rgb_array"
+            else None
         )
 
     def observe(self, agent):
@@ -488,3 +497,6 @@ class raw_env(AECEnv):
         self._cumulative_rewards[self.agent_selection] = 0
         self.agent_selection = self._agent_selector.next()
         self._accumulate_rewards()
+
+        if self.render_mode == "human":
+            self.render()
