@@ -126,7 +126,7 @@ import math
 
 import magent
 import numpy as np
-from gym.utils import EzPickle
+from gymnasium.utils import EzPickle
 
 from pettingzoo.magent.battle.battle import KILL_REWARD, get_config
 from pettingzoo.magent.magent_env import magent_parallel_env, make_env
@@ -148,12 +148,13 @@ def parallel_env(
     max_cycles=max_cycles_default,
     minimap_mode=minimap_mode_default,
     extra_features=False,
+    render_mode=None,
     **reward_args
 ):
     env_reward_args = dict(**default_reward_args)
     env_reward_args.update(reward_args)
     return _parallel_env(
-        map_size, minimap_mode, env_reward_args, max_cycles, extra_features
+        map_size, minimap_mode, env_reward_args, max_cycles, extra_features, render_mode
     )
 
 
@@ -179,9 +180,23 @@ class _parallel_env(magent_parallel_env, EzPickle):
         "render_fps": 5,
     }
 
-    def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
+    def __init__(
+        self,
+        map_size,
+        minimap_mode,
+        reward_args,
+        max_cycles,
+        extra_features,
+        render_mode=None,
+    ):
         EzPickle.__init__(
-            self, map_size, minimap_mode, reward_args, max_cycles, extra_features
+            self,
+            map_size,
+            minimap_mode,
+            reward_args,
+            max_cycles,
+            extra_features,
+            render_mode,
         )
         assert map_size >= 46, "size of map must be at least 46"
         env = magent.GridWorld(
@@ -204,6 +219,7 @@ class _parallel_env(magent_parallel_env, EzPickle):
             reward_range,
             minimap_mode,
             extra_features,
+            render_mode,
         )
 
     def generate_map(self):
