@@ -113,7 +113,7 @@ last_reward(extra_features=True)| 1
 
 import magent
 import numpy as np
-from gym.utils import EzPickle
+from gymnasium.utils import EzPickle
 
 from pettingzoo.magent.magent_env import magent_parallel_env, make_env
 from pettingzoo.utils.conversions import parallel_to_aec_wrapper
@@ -131,12 +131,13 @@ def parallel_env(
     max_cycles=max_cycles_default,
     minimap_mode=minimap_mode_default,
     extra_features=False,
+    render_mode=None,
     **reward_args
 ):
     env_reward_args = dict(**default_reward_args)
     env_reward_args.update(reward_args)
     return _parallel_env(
-        map_size, minimap_mode, env_reward_args, max_cycles, extra_features
+        map_size, minimap_mode, env_reward_args, max_cycles, extra_features, render_mode
     )
 
 
@@ -209,7 +210,15 @@ class _parallel_env(magent_parallel_env, EzPickle):
         "render_fps": 5,
     }
 
-    def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
+    def __init__(
+        self,
+        map_size,
+        minimap_mode,
+        reward_args,
+        max_cycles,
+        extra_features,
+        render_mode=None,
+    ):
         EzPickle.__init__(
             self, map_size, minimap_mode, reward_args, max_cycles, extra_features
         )
@@ -230,6 +239,7 @@ class _parallel_env(magent_parallel_env, EzPickle):
             reward_range,
             minimap_mode,
             extra_features,
+            render_mode,
         )
 
     def generate_map(self):
