@@ -56,10 +56,16 @@ from .._mpe_utils.simple_env import SimpleEnv, make_env
 
 
 class raw_env(SimpleEnv):
-    def __init__(self, max_cycles=25, continuous_actions=False):
+    def __init__(self, max_cycles=25, continuous_actions=False, render_mode=None):
         scenario = Scenario()
         world = scenario.make_world()
-        super().__init__(scenario, world, max_cycles, continuous_actions)
+        super().__init__(
+            scenario=scenario,
+            world=world,
+            render_mode=render_mode,
+            max_cycles=max_cycles,
+            continuous_actions=continuous_actions,
+        )
         self.metadata["name"] = "simple_v2"
 
 
