@@ -57,7 +57,7 @@ simple_spread_v2.env(N=3, local_ratio=0.5, max_cycles=25, continuous_actions=Fal
 """
 
 import numpy as np
-from gym.utils import EzPickle
+from gymnasium.utils import EzPickle
 
 from pettingzoo.utils.conversions import parallel_wrapper_fn
 
@@ -67,20 +67,30 @@ from .._mpe_utils.simple_env import SimpleEnv, make_env
 
 
 class raw_env(SimpleEnv, EzPickle):
-    def __init__(self, N=3, local_ratio=0.5, max_cycles=25, continuous_actions=False):
+    def __init__(
+        self,
+        N=3,
+        local_ratio=0.5,
+        max_cycles=25,
+        continuous_actions=False,
+        render_mode=None,
+    ):
         EzPickle.__init__(
-            self,
-            N,
-            local_ratio,
-            max_cycles,
-            continuous_actions,
+            self, N, local_ratio, max_cycles, continuous_actions, render_mode
         )
         assert (
             0.0 <= local_ratio <= 1.0
         ), "local_ratio is a proportion. Must be between 0 and 1."
         scenario = Scenario()
         world = scenario.make_world(N)
-        super().__init__(scenario, world, max_cycles, continuous_actions, local_ratio)
+        super().__init__(
+            scenario=scenario,
+            world=world,
+            render_mode=render_mode,
+            max_cycles=max_cycles,
+            continuous_actions=continuous_actions,
+            local_ratio=local_ratio,
+        )
         self.metadata["name"] = "simple_spread_v2"
 
 
