@@ -7,7 +7,8 @@ import numpy as np
 
 class AgentLayer:
     def __init__(self, xs, ys, allies, seed=1):
-        """
+        """Initializes the AgentLayer class.
+
         xs: x size of map
         ys: y size of map
         allies: list of ally agents
@@ -19,7 +20,6 @@ class AgentLayer:
         - nactions()
         - set_position(x, y)
         """
-
         self.allies = allies
         self.nagents = len(allies)
         self.global_state = np.zeros((xs, ys), dtype=np.int32)
@@ -34,9 +34,7 @@ class AgentLayer:
         self.allies[agent_idx].set_position(x, y)
 
     def get_position(self, agent_idx):
-        """
-        Returns the position of the given agent
-        """
+        """Returns the position of the given agent."""
         return self.allies[agent_idx].current_position()
 
     def get_nactions(self, agent_idx):
@@ -48,8 +46,8 @@ class AgentLayer:
         self.nagents -= 1
 
     def get_state_matrix(self):
-        """
-        Returns a matrix representing the positions of all allies
+        """Returns a matrix representing the positions of all allies.
+
         Example: matrix contains the number of allies at give (x,y) position
         0 0 0 1 0 0 0
         0 2 0 2 0 0 0
