@@ -6,7 +6,6 @@ import numpy as np
 def random_demo(env, render=True, episodes=1):
     """Runs an env object with random actions."""
     total_reward = 0
-    done = False
     completed_episodes = 0
 
     while completed_episodes < episodes:
@@ -15,9 +14,9 @@ def random_demo(env, render=True, episodes=1):
             if render:
                 env.render()
 
-            obs, reward, done, _ = env.last()
+            obs, reward, termination, truncation, _ = env.last()
             total_reward += reward
-            if done:
+            if termination or truncation:
                 action = None
             elif isinstance(obs, dict) and "action_mask" in obs:
                 action = random.choice(np.flatnonzero(obs["action_mask"]))
