@@ -3,11 +3,9 @@ from .base import BaseWrapper
 
 
 class TerminateIllegalWrapper(BaseWrapper):
-    """
-    this wrapper terminates the game with the current player losing
-    in case of illegal values
+    """This wrapper terminates the game with the current player losing in case of illegal values.
 
-    parameters:
+    Parameters:
         - illegal_reward: number that is the value of the player making an illegal move.
     """
 
@@ -31,22 +29,31 @@ class TerminateIllegalWrapper(BaseWrapper):
         current_agent = self.agent_selection
         if self._prev_obs is None:
             self.observe(self.agent_selection)
+        assert self._prev_obs
         assert (
             "action_mask" in self._prev_obs
         ), "action_mask must always be part of environment observation as an element in a dictionary observation to use the TerminateIllegalWrapper"
         _prev_action_mask = self._prev_obs["action_mask"]
         self._prev_obs = None
-        if self._terminated and self.dones[self.agent_selection]:
-            self._was_done_step(action)
-        elif not self.dones[self.agent_selection] and not _prev_action_mask[action]:
+        if self._terminated and (
+            self.terminations[self.agent_selection]
+            or self.truncations[self.agent_selection]
+        ):
+            self._was_dead_step(action)
+        elif (
+            not self.terminations[self.agent_selection]
+            and not self.truncations[self.agent_selection]
+            and not _prev_action_mask[action]
+        ):
             EnvLogger.warn_on_illegal_move()
             self._cumulative_rewards[self.agent_selection] = 0
-            self.dones = {d: True for d in self.dones}
+            self.terminations = {d: True for d in self.agents}
+            self.truncations = {d: True for d in self.agents}
             self._prev_obs = None
-            self.rewards = {d: 0 for d in self.dones}
+            self.rewards = {d: 0 for d in self.truncations}
             self.rewards[current_agent] = float(self._illegal_value)
             self._accumulate_rewards()
-            self._dones_step_first()
+            self._deads_step_first()
             self._terminated = True
         else:
             super().step(action)
